@@ -1,7 +1,7 @@
 package App::depak;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.49'; # VERSION
 
 use 5.010001;
 use strict;
@@ -302,12 +302,14 @@ sub _build_lib {
 }
 
 sub _pack {
+    require ExtUtils::MakeMaker;
     require File::Find;
 
     my $self = shift;
 
     my $tempdir = $self->{tempdir};
 
+    $self->{_included_modules} = {};
     my %pack_args;
     {
         local $CWD = "$tempdir/lib";
@@ -318,13 +320,18 @@ sub _pack {
                 my $mod_pm = $File::Find::dir eq '.' ? $_ : "$File::Find::dir/$_";
                 $mod_pm =~ s!^\.[/\\]!!;
                 $mod_pm =~ s!\\!/!g; # convert windows-style path
+
+                my $mod = $mod_pm;
+                $mod =~ s/\.pm$//;
+                $mod =~ s!/!::!g;
+
+                my $mod_ver = MM->parse_version($_);
+                $mod_ver = undef if defined($mod_ver) && $mod_ver eq 'undef';
+
                 $pack_args{module_srcs}{$mod_pm} = read_binary($_);
+                $self->{_included_modules}{$mod} = $mod_ver;
             }, ".",
         );
-        $self->{_included_modules} = [
-            map { my $m = $_; $m =~ s!/!::!g; $m =~ s/\.pm$//; $m }
-                sort keys %{ $pack_args{module_srcs} }
-        ];
     }
 
     my $script = read_binary($self->{abs_input_file});
@@ -953,7 +960,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.48 of App::depak (from Perl distribution App-depak), released on 2015-08-18.
+This document describes version 0.49 of App::depak (from Perl distribution App-depak), released on 2015-10-20.
 
 =head1 SYNOPSIS
 
@@ -966,7 +973,9 @@ See L<depak>.
 
 =head2 depak(%args) -> [status, msg, result, meta]
 
-{en_US Pack your dependencies onto your script file}.
+Pack your dependencies onto your script file.
+
+This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -976,9 +985,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<args> => I<array[str]>
 
-{en_US Script arguments}.
+Script arguments.
 
-{en_US 
 Will be used when running your script, e.g. when C<trace_method> is C<fatpacker>
 or C<require>. For example, if your script requires three arguments: C<--foo>,
 C<2>, C<"bar baz"> then you can either use:
@@ -989,49 +997,40 @@ or:
 
  % depak script output --args-json '["--foo",2,"bar baz"]'
 
-}
-
 =item * B<debug_keep_tempdir> => I<bool>
 
-{en_US Keep temporary directory for debugging}.
+Keep temporary directory for debugging.
 
 =item * B<exclude_core> => I<bool> (default: 1)
 
-{en_US Whether to exclude core modules}.
+Whether to exclude core modules.
 
 =item * B<exclude_dist> => I<array[str]>
 
-{en_US Exclude all modules of dist}.
+Exclude all modules of dist.
 
-{en_US 
 Just like the C<exclude> option, but will exclude module as well as other modules
 from the same distribution. Module name must be the main module of the
 distribution. Will determine other modules from the C<.packlist> file.
-}
 
 =item * B<exclude_list> => I<str>
 
-{en_US Exclude modules from a list in a file}.
+Exclude modules from a list in a file.
 
 =item * B<exclude_module> => I<array[str]>
 
-{en_US Modules to exclude}.
+Modules to exclude.
 
-{en_US 
 When you don't want to include a module, specify it here.
-}
 
 =item * B<exclude_pattern> => I<array[str]>
 
-{en_US Regex patterns of modules to exclude}.
+Regex patterns of modules to exclude.
 
-{en_US 
 When you don't want to include a pattern of modules, specify it here.
-}
 
 =item * B<exclude_prereq> => I<array[str]>
 
-{en_US 
 This option can be used to express that script will depend on a specified
 module, instead of including it packed. The prereq-ed module, as well as other
 modules in the same distribution, as well as its prereqs and so on recursively,
@@ -1043,38 +1042,32 @@ cannot be packed.
 To query dependencies, a local CPAN index is used for querying speed. Thus, this
 option requires that C<lcpan> is installed and a fairly recent lcpan index is
 available.
-}
 
 =item * B<include_dir> => I<array[str]>
 
-{en_US Include extra modules under directories}.
+Include extra modules under directories.
 
 =item * B<include_dist> => I<array[str]>
 
-{en_US Include all modules of dist}.
+Include all modules of dist.
 
-{en_US 
 Just like the C<include> option, but will include module as well as other modules
 from the same distribution. Module name must be the main module of the
 distribution. Will determine other modules from the C<.packlist> file.
-}
 
 =item * B<include_list> => I<str>
 
-{en_US Include extra modules from a list in a file}.
+Include extra modules from a list in a file.
 
 =item * B<include_module> => I<array[str]>
 
-{en_US Include extra modules}.
+Include extra modules.
 
-{en_US 
 When the tracing process fails to include a required module, you can add it
 here.
-}
 
 =item * B<include_prereq> => I<array[str]>
 
-{en_US 
 This option can be used to include a module, as well as other modules in the
 same distribution as that module, as well as the distribution's recursive
 dependencies, for packing. Dependencies will be searched using a local CPAN
@@ -1083,38 +1076,32 @@ to use this option together with setting C<trace_method> to C<none>.
 
 This option requires that C<lcpan> is installed and a fairly recent lcpan index
 is available.
-}
 
 =item * B<input_file> => I<str> (default: "-")
 
-{en_US Path to input file (script to be packed)}.
+Path to input file (script to be packed).
 
-{en_US 
 C<-> (or if unspecified) means to take from standard input (internally, a
 temporary file will be created to handle this).
-}
 
 =item * B<multiple_runs> => I<array[hash]>
 
-{en_US Pass to tracepm}.
+Pass to tracepm.
 
 =item * B<output_file> => I<str> (default: "-")
 
-{en_US Path to output file}.
+Path to output file.
 
-{en_US 
 C<-> (or if unspecified) means to output to stdout.
-}
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-{en_US Whether to overwrite output if previously exists}.
+Whether to overwrite output if previously exists.
 
 =item * B<pack_method> => I<str> (default: "fatpack")
 
-{en_US Packing method to use}.
+Packing method to use.
 
-{en_US 
 Either C<fatpack> (the default) or C<datapack>. Fatpack puts packed modules inside
 Perl variables and load them via require hook. Datapack puts packed modules in
 B<DATA> section. For more details about each method, please consult
@@ -1124,93 +1111,82 @@ One thing to remember is, with datapack, your script cannot load modules during
 compile-time (C<use>): all modules must be loaded during run-time (C<require>)
 when data section is already available. Also, your script currently cannot
 contain data section of its own.
-}
 
 =item * B<perl_version> => I<str>
 
-{en_US Perl version to target, defaults to current running version}.
+Perl version to target, defaults to current running version.
 
-{en_US 
 This is for determining which modules are considered core and should be skipped
 by default (when C<exclude_core> option is enabled). Different perl versions have
 different sets of core modules as well as different versions of the modules.
-}
 
 =item * B<shebang> => I<str> (default: "/usr/bin/perl")
 
-{en_US Set shebang line/path}.
+Set shebang line/path.
 
 =item * B<skip_not_found> => I<bool> (default: 1)
 
-{en_US Instead of dying, skip when module to add is not found}.
+Instead of dying, skip when module to add is not found.
 
-{en_US 
 This option is useful when you use C<include_prereq>, because modules without its
 own .pm files will also be included (CPAN indexes packages, including those that
 do not have their own .pm files).
-}
 
 =item * B<squish> => I<bool> (default: 0)
 
-{en_US Whether to squish included modules using Perl::Squish}.
+Whether to squish included modules using Perl::Squish.
 
 =item * B<strip> => I<bool> (default: 0)
 
-{en_US Whether to strip included modules using Perl::Strip}.
+Whether to strip included modules using Perl::Strip.
 
 =item * B<stripper> => I<bool> (default: 0)
 
-{en_US Whether to strip included modules using Perl::Stripper}.
+Whether to strip included modules using Perl::Stripper.
 
 =item * B<stripper_comment> => I<bool> (default: 1)
 
-{en_US Set strip_comment=1 (strip comments) in Perl::Stripper}.
+Set strip_comment=1 (strip comments) in Perl::Stripper.
 
 =item * B<stripper_log> => I<bool> (default: 0)
 
-{en_US Set strip_log=1 (strip log statements) in Perl::Stripper}.
+Set strip_log=1 (strip log statements) in Perl::Stripper.
 
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
-{en_US Set maintain_linum=1 in Perl::Stripper}.
+Set maintain_linum=1 in Perl::Stripper.
 
 =item * B<stripper_pod> => I<bool> (default: 1)
 
-{en_US Set strip_pod=1 (strip POD) in Perl::Stripper}.
+Set strip_pod=1 (strip POD) in Perl::Stripper.
 
 =item * B<stripper_ws> => I<bool> (default: 1)
 
-{en_US Set strip_ws=1 (strip whitespace) in Perl::Stripper}.
+Set strip_ws=1 (strip whitespace) in Perl::Stripper.
 
 =item * B<test> => I<bool>
 
-{en_US Test the resulting output}.
+Test the resulting output.
 
-{en_US 
 Testing is done by running the resulting packed script with perl. To test, at
 least one test case is required (see C<--test-case-json>). Test cases specify
 what arguments to give to program, what exit code we expect, and what the output
 should contain.
-}
 
 =item * B<test_cases> => I<array[hash]>
 
-{en_US 
 Example case:
 
  {"args":["--help"], "exit_code":0, "perl_args":["-Mlib::core::only"], "output_like":"Usage:"}
 
-}
-
 =item * B<trace_extra_opts> => I<hash>
 
-{en_US Pass more options to `App::tracepm`}.
+Pass more options to `App::tracepm`.
 
 =item * B<trace_method> => I<str> (default: "fatpacker")
 
-{en_US Which method to use to trace dependencies}.
+Which method to use to trace dependencies.
 
-{en_US 
 The default is C<fatpacker>, which is the same as what C<fatpack trace> does.
 Different tracing methods have different pro's and con's, one method might
 detect required modules that another method does not, and vice versa. There are
@@ -1218,16 +1194,13 @@ several methods available, please see C<App::tracepm> for more details.
 
 A special value of C<none> is also provided. If this is selected, then depak will
 not perform any tracing. Usually used in conjunction with C<--include-from>.
-}
 
 =item * B<use> => I<array[str]>
 
-{en_US Additional modules to "use"}.
+Additional modules to "use".
 
-{en_US 
 Will be passed to the tracer. Will currently only affect the C<fatpacker> and
 C<require> methods (because those methods actually run your script).
-}
 
 =back
 
